@@ -10,8 +10,7 @@
 #'
 #' @return A lifemap_obj object.
 #' @export
-lifemap <- function(lm_obj,
-                    zoom = 4) {
+lifemap <- function(lm_obj, zoom = 4) {
   lm_obj$options <- list(zoom = zoom)
   return(lm_obj)
 }
